@@ -74,7 +74,7 @@ NotificationMonitor::NotificationMonitor(QWidget *parent) :
     hLayout->addWidget(mTypeFilterCombo = new KCheckComboBox(this));
     hLayout->addStretch();
     mTypeFilterCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);
-    mTypeFilterCombo->setMinimumWidth(fontMetrics().width(QStringLiteral("Subscription,Items,Collections")) + 60); // make it wide enough for most use cases
+    mTypeFilterCombo->setMinimumWidth(fontMetrics().boundingRect(QStringLiteral("Subscription,Items,Collections")).width() + 60); // make it wide enough for most use cases
     m_filterModel->setTypeFilter(mTypeFilterCombo);
 
     m_splitter = new QSplitter(this);
@@ -305,7 +305,7 @@ void NotificationMonitor::populateItemTree(QStandardItem *parent, const Akonadi:
     appendRow(parent, QStringLiteral("Flags"), toString(item.flags()));
     auto tagItem = new QStandardItem(QStringLiteral("Tags"));
     const auto tags = item.tags();
-    for (const auto tag : tags) {
+    for (const auto &tag : tags) {
         auto item = new QStandardItem(QString::number(tag.id()));
         populateTagTree(item, tag);
         tagItem->appendRow(item);
@@ -315,7 +315,7 @@ void NotificationMonitor::populateItemTree(QStandardItem *parent, const Akonadi:
     appendRow(parent, QStringLiteral("VRefs"), toString(item.virtualReferences()));
     auto relationItem = new QStandardItem(QStringLiteral("Relations"));
     const auto relations = item.relations();
-    for (const auto relation : relations) {
+    for (const auto &relation : relations) {
         auto item = new QStandardItem(QStringLiteral("%lld-%lld %s").arg(QString::number(relation.left()), QString::number(relation.right()), QString::fromUtf8(relation.type())));
         relationItem->appendRow(item);
     }
@@ -391,7 +391,6 @@ void NotificationMonitor::populateCollectionTree(QStandardItem *parent, const Ak
     appendRow(parent, QStringLiteral("DisplayPref"), toString(collection.displayPref()));
     appendRow(parent, QStringLiteral("SyncPref"), toString(collection.syncPref()));
     appendRow(parent, QStringLiteral("IndexPref"), toString(collection.indexPref()));
-    appendRow(parent, QStringLiteral("Referenced"), toString(collection.referenced()));
     appendRow(parent, QStringLiteral("Virtual"), toString(collection.isVirtual()));
 }
 
